==> zio-aws-auditmanager_2.13-5.17.126.2-sources.jar: zio/aws/auditmanager/model/ControlInsightsMetadataByAssessmentItem.scala <==
package zio.aws.auditmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.auditmanager.model.primitives.{Timestamp, UUID, NonEmptyString}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class ControlInsightsMetadataByAssessmentItem(
    name: Option[NonEmptyString] = None,
    id: Option[UUID] = None,
    evidenceInsights: Option[zio.aws.auditmanager.model.EvidenceInsights] =
      None,
    controlSetName: Option[NonEmptyString] = None,
    lastUpdated: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem = {
    import ControlInsightsMetadataByAssessmentItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(id.map(value => UUID.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(evidenceInsights.map(value => value.buildAwsValue()))(
        _.evidenceInsights
      )
      .optionallyWith(
        controlSetName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.controlSetName)
      .optionallyWith(
        lastUpdated.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastUpdated)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly =
    zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem
      .wrap(buildAwsValue())
}
object ControlInsightsMetadataByAssessmentItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem =
      zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem(
        name.map(value => value),
        id.map(value => value),
        evidenceInsights.map(value => value.asEditable),
        controlSetName.map(value => value),
        lastUpdated.map(value => value)
      )
    def name: Option[NonEmptyString]
    def id: Option[UUID]
    def evidenceInsights
        : Option[zio.aws.auditmanager.model.EvidenceInsights.ReadOnly]
    def controlSetName: Option[NonEmptyString]
    def lastUpdated: Option[Timestamp]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, UUID] = AwsError.unwrapOptionField("id", id)
    def getEvidenceInsights: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.EvidenceInsights.ReadOnly
    ] = AwsError.unwrapOptionField("evidenceInsights", evidenceInsights)
    def getControlSetName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("controlSetName", controlSetName)
    def getLastUpdated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastUpdated", lastUpdated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ) extends zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly {
    override val name: Option[NonEmptyString] = scala
      .Option(impl.name())
      .map(value => zio.aws.auditmanager.model.primitives.NonEmptyString(value))
    override val id: Option[UUID] = scala
      .Option(impl.id())
      .map(value => zio.aws.auditmanager.model.primitives.UUID(value))
    override val evidenceInsights
        : Option[zio.aws.auditmanager.model.EvidenceInsights.ReadOnly] = scala
      .Option(impl.evidenceInsights())
      .map(value => zio.aws.auditmanager.model.EvidenceInsights.wrap(value))
    override val controlSetName: Option[NonEmptyString] = scala
      .Option(impl.controlSetName())
      .map(value => zio.aws.auditmanager.model.primitives.NonEmptyString(value))
    override val lastUpdated: Option[Timestamp] = scala
      .Option(impl.lastUpdated())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ): zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-auditmanager_2.13-5.17.214.1-sources.jar: zio/aws/auditmanager/model/ControlInsightsMetadataByAssessmentItem.scala <==
package zio.aws.auditmanager.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.auditmanager.model.primitives.{Timestamp, UUID, NonEmptyString}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ControlInsightsMetadataByAssessmentItem(
    name: Optional[NonEmptyString] = Optional.Absent,
    id: Optional[UUID] = Optional.Absent,
    evidenceInsights: Optional[zio.aws.auditmanager.model.EvidenceInsights] =
      Optional.Absent,
    controlSetName: Optional[NonEmptyString] = Optional.Absent,
    lastUpdated: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem = {
    import ControlInsightsMetadataByAssessmentItem.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
      .builder()
      .optionallyWith(
        name.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(id.map(value => UUID.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(evidenceInsights.map(value => value.buildAwsValue()))(
        _.evidenceInsights
      )
      .optionallyWith(
        controlSetName.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.controlSetName)
      .optionallyWith(
        lastUpdated.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastUpdated)
      .build()
  }
  def asReadOnly
      : zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly =
    zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem
      .wrap(buildAwsValue())
}
object ControlInsightsMetadataByAssessmentItem {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem =
      zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem(
        name.map(value => value),
        id.map(value => value),
        evidenceInsights.map(value => value.asEditable),
        controlSetName.map(value => value),
        lastUpdated.map(value => value)
      )
    def name: Optional[NonEmptyString]
    def id: Optional[UUID]
    def evidenceInsights
        : Optional[zio.aws.auditmanager.model.EvidenceInsights.ReadOnly]
    def controlSetName: Optional[NonEmptyString]
    def lastUpdated: Optional[Timestamp]
    def getName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("name", name)
    def getId: ZIO[Any, AwsError, UUID] = AwsError.unwrapOptionField("id", id)
    def getEvidenceInsights: ZIO[
      Any,
      AwsError,
      zio.aws.auditmanager.model.EvidenceInsights.ReadOnly
    ] = AwsError.unwrapOptionField("evidenceInsights", evidenceInsights)
    def getControlSetName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("controlSetName", controlSetName)
    def getLastUpdated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastUpdated", lastUpdated)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ) extends zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly {
    override val name: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.auditmanager.model.primitives.NonEmptyString(value))
    override val id: Optional[UUID] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.auditmanager.model.primitives.UUID(value))
    override val evidenceInsights
        : Optional[zio.aws.auditmanager.model.EvidenceInsights.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.evidenceInsights())
        .map(value => zio.aws.auditmanager.model.EvidenceInsights.wrap(value))
    override val controlSetName: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.controlSetName())
        .map(value =>
          zio.aws.auditmanager.model.primitives.NonEmptyString(value)
        )
    override val lastUpdated: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdated())
      .map(value => zio.aws.auditmanager.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.auditmanager.model.ControlInsightsMetadataByAssessmentItem
  ): zio.aws.auditmanager.model.ControlInsightsMetadataByAssessmentItem.ReadOnly =
    new Wrapper(impl)
}
